@@ -355,13 +355,12 @@ class GitLibMixin:
         return self._repo.revparse_single(branch).tree
 
     def _getTree(self, path: Path) -> pygit2.Tree:
-        if path.as_posix().startswith("./"):
-            raise PathNameInvalidException("Paths should not be relative")
-
         # We will read objects as they are at the working branch
         tree = self.__workingTree
         climbedPath = ""
         for pathComponent in path.as_posix().split("/"):
+            if pathComponent == ".":
+                continue
             climbedPath += f"/{pathComponent}"
             if pathComponent in tree:
                 tree = tree / pathComponent
